@@ -19,20 +19,39 @@
 # THE SOFTWARE.
 
 require 'rspec/files/leaks'
+require 'rspec/core/sandbox'
+require 'tempfile'
 
-RSpec.describe "leaks context" do
+RSpec.describe RSpec::Files::Leaks do
 	include_context RSpec::Files::Leaks
 	
-	it "leaks io" do
+	it "leaks IO instances" do
 		expect(before_ios).to be == current_ios
-		
+	
 		input, output = IO.pipe
-		
+	
 		expect(before_ios).to_not be == current_ios
-		
+	
 		input.close
 		output.close
-		
+	
 		expect(before_ios).to be == current_ios
 	end
+	
+	it "fails if it leaks IO instances" do
+		group = RSpec::Core::Sandbox.sandboxed{RSpec.describe}
+		group.include_context RSpec::Files::Leaks
+		
+		pipe = nil
+		
+		group.example("leaky example") do
+			pipe = IO.pipe
+		end
+		
+		result = group.run
+		
+		pipe.each(&:close)
+		
+		expect(result).to be_falsy
+	end
 end
